@@ -5,6 +5,7 @@ import matplotlib.colors
 import numpy as np
 import os
 from pathlib import Path
+from pkg_resources import resource_filename
 import shutil
 import subprocess
 
@@ -23,7 +24,8 @@ class Registration(Data):
     def __init__(
         self, path, fixed=None, moving=None, fixed_mask=None,
         moving_mask=None, pfiles=None, auto=False, overwrite=False,
-        tfiles={}, capture_output=False, log_level=None):
+        tfiles=None, initial_alignment=None, initial_transform_name=None,
+        capture_output=False, log_level=None):
         """Load data for an image registration and run the registration if
         auto_seg=True.
 
@@ -60,7 +62,6 @@ class Registration(Data):
             None and an image file 'moving_mask.nii.gz' exists at <path>
             then this will be used.  Setting a mask is optional.
 
-
         pfiles : str/list/dict, default=None
             Path(s) to elastix parameter file(s) to be used in each step of the
             registration. If a list of more than one path, the parameter files
@@ -81,11 +82,36 @@ class Registration(Data):
             If True and <path> already contains files, these will be deleted,
             meaning that no prior registration results will be loaded.
 
-        tfiles: dict, default={}
-            Dictionary of pre-defined transforms, where a keys is a
+        tfiles : dict, default=None
+            Dictionary of pre-defined transforms, where a key is a
             registration step and the associated value is the path to
-            a pre-defined registration transform.  This parameter is
-            considered only if pfiles is null.
+            a pre-defined registration transform.  Transformations
+            are performed, in the order given in the dictionary,
+            before any registration step is performed.
+
+        initial_alignment : tuple/dict/str, default=None
+            Alignment to be performed before any registration steps
+            are run.  This can be any of the following:
+            - a tuple indicating the amounts (dx, dy, dz) by which
+              a point in the fixed image must be translated to align
+              with the corresponding point in the moving image;
+            - a dictionary specifying parameters and values to be passed
+              to skrt.image.get_translation_to_align(), which defines
+              a translation for aligning fixed and moving image;
+            - one of the strings "top", "centre", "bottom", in which case
+              skrt.image.get_translation_to align() is called to define
+              a translationg such that fixed and moving image have
+              their (x, y) centres aligned, and have z positions aligned at
+              image top, centre or bottom.
+            The result of the initial alignment is stored as the first
+            entry of <self.tfiles", with key <initial_alignment_name>.  If
+            <initial_alignment> is set to None, no initial alignment
+            is performed.
+
+        initial_transform_name : str, default=None
+            Name to be used in registration steps for transform corresponding
+            to <initial_alignment>.  If None, the name 'initial_alignment'
+            is used.
 
         capture_output : bool, default=False
             If True, capture to stdout messages from performing
@@ -131,6 +157,14 @@ class Registration(Data):
         if fixed is None and moving is None:
             self.load_existing_input_images()
 
+        # Set initial transform corresponding to initial alignment.
+        initial_translation = self.get_initial_translation(initial_alignment)
+        if initial_translation:
+            initial_transform_name = (initial_transform_name
+                    or "initial_alignment")
+            tfiles = tfiles or {}
+            tfiles = {initial_transform_name: initial_translation, **tfiles}
+
         # Set up registration steps
         self.steps = []
         self.steps_file = os.path.join(self.path, "registration_steps.txt")
@@ -140,20 +174,17 @@ class Registration(Data):
         self.transformed_images = {}
         self.jacobians = {}
         self.deformation_fields = {}
-        if isinstance(pfiles, (str, Path)):
-            pfiles = [str(pfiles)]
-        if pfiles is not None:
-            self.add_pfiles(pfiles)
-        else:
-            self.load_pfiles()
+        self.file_types = {'t': tfiles, 'p': pfiles}
+        for ftype, files in self.file_types.items():
+            if isinstance(files, (str, Path)):
+                files = [str(files)]
+            if files is not None:
+                self.add_files(files, ftype)
+        if not self.pfiles and not self.tfiles:
+            self.load_files()
         self.moving_grid_path = os.path.join(self.path, "moving_grid.nii.gz")
         self.transformed_grids = {}
 
-        if not self.pfiles:
-            self.tfiles = tfiles
-            for step in sorted(tfiles):
-                self.steps.append(step)
-
         # Perform registration
         if auto:
             self.register()
@@ -229,18 +260,104 @@ class Registration(Data):
                 return
             self.set_image(path, category, force=False)
 
-    def add_pfile(self, pfile, name=None, params=None):
-        """Add a single parameter file to the list of registration steps.
-        This parameter file can optionally be modified by providing a dict
+    def get_initial_translation(self, initial_alignment=None):
+        """
+        Obtain translation corresponding to intial alignemnt.
+
+        initial_alignment : tuple/dict/str, default=None
+            Alignment to be performed before any registration steps
+            are run.  This can be any of the following:
+            - a tuple indicating the amounts (dx, dy, dz) by which
+              a point in the fixed image must be translated to align
+              with the corresponding point in the moving image;
+            - a dictionary specifying parameters and values to be passed
+              to skrt.image.get_translation_to_align(), which defines
+              a translation for aligning fixed and moving image;
+            - one of the strings "top", "centre", "bottom", in which case
+              skrt.image.get_translation_to align() is called to define
+              a translationg such that fixed and moving image have
+              their (x, y) centres aligned, and have z positions aligned at
+              image top, centre or bottom.
+            The result of the initial alignment is stored as the first
+            entry of <self.tfiles", with key <initial_alignment_name>.  If
+            <initial_alignment> is set to None, no initial alignment
+            is performed.
+        """
+        if not (initial_alignment and self.fixed_image and self.moving_image):
+            return
+
+        # If initial alignment specified as a tuple, return this.
+        if isinstance(initial_alignment, tuple):
+            return initial_alignment
+
+        # If needed, create alignment dictionary based on string.
+        valid_alignments = ["bottom", "centre", "top"]
+        if initial_alignment in valid_alignments:
+            initial_alignment = {"alignments": {"x": 2, "y": 2, "z":
+                    1 + valid_alignments.index(initial_alignment)}}
+
+        # Define translation for initial alignment.
+        if isinstance(initial_alignment, dict):
+            # Need to use standardised versions of fixed and moving image.
+            initial_translation = skrt.image.get_translation_to_align(
+                  skrt.image.Image(
+                       self.fixed_image.get_standardised_data(),
+                       affine=self.fixed_image.get_standardised_affine()),
+                   skrt.image.Image(
+                       self.moving_image.get_standardised_data(),
+                       affine=self.moving_image.get_standardised_affine()),
+                        **initial_alignment)
+        else:
+            initial_translation = None
+            self.logger.warning(
+                    f"Invalid initial_alignment: {initial_alignment}")
+            self.logger.warning("Value for initial alignment should be "
+                    "a dictionary to be passed to "
+                    "skrt.image.get_translation_to_align()")
+            self.logger.warning(f"or one of the strings: {valid_alignments}")
+
+        return initial_translation
+
+    def define_translation(self, dxdydz):
+        """
+        Define Elastix translation parameters from 3-element tuple or list.
+
+        **Parameter:**
+
+        dxdydz : tuple/list
+            Three-element tuple or list, giving translation in order (x, y, z).
+        """
+        # Define translation parameters that are enough to allow
+        # application before a registration step.
+        translation = {
+                "Transform": "TranslationTransform",
+                "NumberOfParameters": 3,
+                "TransformParameters": dxdydz,
+                "InitialTransformParametersFileName": "NoInitialTransform",
+                "UseBinaryFormatForTransformationParameters": False,
+                "HowToCombineTransforms": "Compose"
+                }
+
+        if hasattr(self, "fixed_image"):
+            # Add parameters needed to allow warping of the moving image.
+            translation.update(get_image_transform_parameters(self.fixed_image))
+
+        return translation
+
+    def add_file(self, file, name=None, params=None, ftype="p"):
+        """Add a single file of type <ftype> to the list of registration steps.
+        This file can optionally be modified by providing a dict
         of parameter names and new values in <params>.
 
         **Parameters:**
 
-        pfile : str/dict
+        file : str/dict/tuple/list
             Path to the elastix parameter file to copy into the registration
             directory. Can also be a dict containing parameters and values,
             which will be used to create a parameter file from scratch. In this
-            case, the <name> argument must also be provided.
+            case, the <name> argument must also be provided.  For a transform
+            file (<ftype> of 't'), can also be a three element tuple or list,
+            specifying the x, y, z components of a translation.
 
         name : str, default=None
             Name for this step of the registration. If None, a name will
@@ -249,15 +366,44 @@ class Registration(Data):
         params : dict, default=None
             Dictionary of parameter names and replacement values with which
             the input parameter file will be modified.
-        """
 
-        # Infer name from parameter file name if name is None
-        if name is None:
-            if isinstance(pfile, dict):
-                self.logger.warning(
-                        "If passing parameters from dict, <name> must be set.")
+        ftype : str, default='p'
+            String indicating whether the file to be added is a parameter
+            file ('p') or a transform file ('t').
+        """
+        # Check that file type is recognised.
+        if not ftype.lower() in self.file_types:
+            self.logger.warning(f"File ignored: '{file}'")
+            self.logger.warning(f"File type not recognised: '{ftype}'")
+            self.logger.warning(f"\nValid file types are: '{self.file_types}'")
+            return
+        ftype = ftype.lower()
+
+        # Only allow file to be passed as a list or tuple
+        # if it has exactly three elements and is for a transform file.
+        if isinstance(file, (tuple, list)):
+            if len(file) != 3:
+                self.logger.warning("Input for file: '{file}'")
+                self.logger.warning("Translation passed as list or tuple "
+                        "must contain exactly 3 elements")
                 return
-            name = os.path.basename(fullpath(pfile)).replace(".txt", "")
+            if ftype != 't':
+                self.logger.warning(f"Translation may only be passes as list "
+                        "or tuple for transform")
+                return
+
+        # If name is null, infer from file name.
+        if not name:
+            if isinstance(file, (dict, tuple, list)):
+                self.logger.warning(
+                        "If passing parameters from dict, tuple or list, "
+                        "<name> must be set.")
+                return
+            name = Path(file).stem
+
+        # Create dictionary for translation from list or tuple
+        if isinstance(file, (tuple, list)):
+            file = self.define_translation(file)
 
         # Check whether name already exists and add counter if so
         i = 1
@@ -276,29 +422,44 @@ class Registration(Data):
         os.mkdir(outdir)
         self.outdirs[name] = outdir
 
-        # If pfile already exists, copy it into output dir
-        path = f"{outdir}/InputParameters.txt"
-        shutil.copy(pfile, path)
-        self.pfiles[name] = path
+        # Define and store file path in step output directory.
+        if "p" == ftype.lower():
+            path = f"{outdir}/InputParameters.txt"
+            self.pfiles[name] = path
+        elif "t" == ftype.lower():
+            path = f"{outdir}/TransformParameters.0.txt"
+            self.tfiles[name] = path
 
-        # Modify the pfile if custom parameters are given
+        # Create new file, or copy existing file.
+        if isinstance(file, dict):
+            Path(path).touch()
+            self.adjust_file(name, file, ftype)
+        else:
+            shutil.copy(file, path)
+
+        # Modify the file if custom parameters are given
         if params is not None:
-            self.adjust_pfile(name, params)
+            self.adjust_file(name, params, ftype)
 
         # Rewrite text file containing list of steps
         self.write_steps()
 
-    def add_pfiles(self, pfiles):
-        """Add multiple parameter files to the list of registration steps,
-        then write list of registration steps to a file."""
+    def add_files(self, files, ftype='p'):
+        """Add multiple files of type <ftype> to the list of registration steps,
+        then write list of registration steps to a file.
 
-        for p in pfiles:
-            if isinstance(pfiles, dict):
-                name = p
-                p = pfiles[p]
+        The valid values for <ftype? are:
+        - 'p': parameter file;
+        - 't': transform file.
+        """
+
+        for f in files:
+            if isinstance(files, dict):
+                name = f
+                f = files[f]
             else:
                 name = None
-            self.add_pfile(p, name=name)
+            self.add_file(f, name=name, ftype=ftype)
 
         self.write_steps()
 
@@ -358,8 +519,8 @@ class Registration(Data):
             return
 
         full_files = get_default_pfiles(False)
-        pfile = full_files[files.index(filename)]
-        self.add_pfile(pfile, params=params)
+        pfile = str(full_files[files.index(filename)])
+        self.add_file(pfile, params=params, ftype="p")
 
     def write_steps(self):
         """Write list of registration steps to a file at
@@ -369,7 +530,7 @@ class Registration(Data):
             for step in self.steps:
                 file.write(step + "\n")
 
-    def load_pfiles(self):
+    def load_files(self):
         """Attempt to load registration steps from a registration step
         file."""
 
@@ -399,20 +560,21 @@ class Registration(Data):
                 continue
 
             pfile = os.path.join(outdir, "InputParameters.txt")
-            if not os.path.exists(pfile):
+            tfile = os.path.join(outdir, "TransformParameters.0.txt")
+            if not os.path.exists(pfile) and not os.path.exists(tfile):
                 self.logger.warning(
-                    f"No parameter file ({outdir}/InputParameters.txt) "
+                    f"No parameter file ({pfile}) "
+                    f"and no transform file ({tfile}) "
                     f"found for registration step {step} listed in "
                     f"{self.steps_file}. This step will be ignored."
                 )
                 continue
 
+            # Add step to the list.
             self.steps.append(step)
             self.outdirs[step] = outdir
-            self.pfiles[step] = pfile
-
-            # Check for transform parameter files
-            tfile = os.path.join(outdir, "TransformParameters.0.txt")
+            if os.path.exists(pfile):
+                self.pfiles[step] = pfile
             if os.path.exists(tfile):
                 self.tfiles[step] = tfile
 
@@ -498,7 +660,8 @@ class Registration(Data):
 
         return cmd
 
-    def register(self, step=None, force=False, use_previous_tfile=True):
+    def register(self, step=None, force=False, use_previous_tfile=True,
+            ensure_transformed_moving=True):
         """Run a registration. By default the registration will be run for
         all steps in self.steps, but can optionally be run for just one step
         by setting <step> to a step name or number. Note that if
@@ -521,6 +684,11 @@ class Registration(Data):
         use_previous_tfile : bool, default=True
             If True, each step will use the transform file from the previous
             step as an initial transform.
+
+        ensure_transformed_moving : bool, default=True
+            Ensure that a transformed moving image is created for each
+            registration step.  This may mean forcing the image creation
+            for a step with a pre-defined transform file.
         """
 
         # Make list of steps to run
@@ -538,10 +706,14 @@ class Registration(Data):
 
         # Run registration for each step
         for step in steps:
-            self.register_step(step, force=force, use_previous_tfile=True)
+            self.register_step(step, force=force,
+                    use_previous_tfile=use_previous_tfile,
+                    ensure_transformed_moving=ensure_transformed_moving)
 
-    def register_step(self, step, force=False, use_previous_tfile=True):
-        """Run a single registration step. Note that if use_previous_tfile=True,
+    def register_step(self, step, force=False, use_previous_tfile=True,
+            ensure_transformed_moving=True):
+        """Run a single registration step, if it has a parameter file
+        assigned. Note that if use_previous_tfile=True,
         any prior steps that have not yet been run will be run.
 
         **Parameters:**
@@ -552,7 +724,9 @@ class Registration(Data):
 
         force : bool, default=None
             If False and a registration has already been performed for the
-            given step, the registration will not be re-run. Note that setting
+            given step, the registration will not be re-run. Ignored
+            if the step has no parameter file assigned (in which case
+            the step must have a pre-defined transform file).  Note that setting
             force=True will only force rerunning of the chosen step, not of
             any preceding steps needed for the input transform file. To enforce
             rerunning of multiple steps, call self.register(step, force=True)
@@ -563,19 +737,32 @@ class Registration(Data):
             step as an initial transform, unless it is the first step. Note
             that this will cause any prior steps that have not yet been run
             to be run.
+
+        ensure_transformed_moving : bool, default=True
+            Ensure that a transformed moving image is created for the
+            registration step.  This may mean forcing the image creation
+            for a step with a pre-defined transform file.
         """
         global _ELASTIX
 
         # Check if the registration has already been performed
         if self.is_registered(step) and not force:
+            if ensure_transformed_moving:
+                self.transform_moving_image(step)
+            return
+        
+        # Obtain step index and name.
+        i = self.get_step_number(step)
+        step = self.get_step_name(step)
+
+        # Check that step has pfile assigned (i.e. it can be run/rerun).
+        if not self.pfiles[step]:
             return
 
         # Check that previous step has been run if needed
-        i = self.get_step_number(step)
-        step = self.get_step_name(step)
         if use_previous_tfile and i > 0:
             if not self.is_registered(i - 1):
-                self.register(i, use_previous_tfile=True)
+                self.register(i - 1, use_previous_tfile=True)
 
         # Run
         cmd = self.get_ELASTIX_cmd(step, use_previous_tfile)
@@ -983,8 +1170,8 @@ class Registration(Data):
         if os.path.exists(self._tmp_dir):
             shutil.rmtree(self._tmp_dir)
 
-    def adjust_pfile(self, step, params, reset=True):
-        """Adjust parameters in an input parameter file for a given step. 
+    def adjust_file(self, step, params, ftype='p', reset=True):
+        """Adjust parameters in a parameter or transform file for a given step. 
 
         **Parameters:**
 
@@ -999,13 +1186,32 @@ class Registration(Data):
             Parameters in the existing file but not in <params> will remain
             unchanged.
 
+        ftype : str, default='p'
+            String indicating whether the file to be added is a parameter
+            file ('p') or a transform file ('t').
+
         reset : bool, default=True
-            If True, this will remove existing registration results.
+            If True, and the step can be rerun (that is, it has a
+            parameter file assigne), this will remove existing
+            registration transforms.
         """
+        # Check that file type is recognised.
+        if not ftype.lower() in self.file_types:
+            self.logger.warning(f"File ignored: '{file}'")
+            self.logger.warning(f"File type not recognised: '{ftype}'")
+            self.logger.warning(f"\nValid file types are: '{self.file_types}'")
+            return
+        ftype = ftype.lower()
 
         step = self.get_step_name(step)
-        adjust_parameters(self.pfiles[step], self.pfiles[step], params)
-        if reset and step in self.tfiles:
+
+        if "p" == ftype:
+            adjust_parameters(self.pfiles[step], self.pfiles[step], params)
+        elif "t" == ftype:
+            adjust_parameters(self.tfiles[step], self.tfiles[step], params)
+
+        if (reset and step in self.tfiles
+                and os.path.exists(self.pfiles.get(step, ""))):
             del self.tfiles[step]
 
     def view_init(self, **kwargs):
@@ -1147,15 +1353,21 @@ class Registration(Data):
 
     def get_step_name(self, step):
         """Convert <step> to a string containing a step name. If <step> is
-        already a string, check it's a valid step and return it; otherwise
-        if <step> is an integer, return the corresponding step name."""
+        already a string, use this; otherwise if <step> is an integer,
+        obtain the corresponding step name.  Check that step has
+        a parameter file and/or a transform file assigned."""
 
         if isinstance(step, str):
-            if step not in self.steps:
+            if not step in self.steps:
                 raise RuntimeError(f"Step {step} not a valid registration step")
-            return step
+        else:
+            step = self.steps[step]
+
+        if not self.pfiles.get(step, None) and not self.tfiles.get(step, None):
+            raise RuntimeError(f"Step {step} not a valid registration step"
+                    f"\nStep{step} has neither pfile nor tfile assigned")
         
-        return self.steps[step]
+        return step
 
     def get_step_number(self, step):
         """Convert <step> to an int containing the number of a given step.
@@ -1881,17 +2093,23 @@ def adjust_parameters(infile, outfile, params):
         Dictionary of parameter names and new values.
     """
 
+    # Check that file to be adjusted exists.
+    if not os.path.exists(infile):
+        self.logger.warning(f"File not found: '{infile}'")
+        self.logger.warning("\nNo parameter-adjustment performed")
+        return
+
     # Read input
     original_params = read_parameters(infile)
     original_params.update(params)
     write_parameters(outfile, original_params)
 
-
 def read_parameters(infile):
     """Get dictionary of parameters from an elastix parameter file."""
 
     lines = [line for line in open(infile).readlines() if line.startswith("(")]
-    lines = [line[line.find("(") + 1 : line.find(")")].split() for line in lines]
+    lines = [line[line.find("(") + 1 : line.rfind(")")].split()
+            for line in lines]
     params = {line[0]: " ".join(line[1:]) for line in lines}
     for name, param in params.items():
         if '"' in param:
@@ -1901,7 +2119,7 @@ def read_parameters(infile):
             elif params[name] == "true":
                 params[name] = True
         elif len(param.split()) > 1:
-            params[name] = [p for p in param.split()]
+            params[name] = [p for p in param.rstrip("(").split()]
             if "." in params[name][0]:
                 params[name] = [float(p) for p in params[name]]
             else:
@@ -1919,17 +2137,20 @@ def write_parameters(outfile, params):
 
     file = open(outfile, "w")
     for name, param in params.items():
-        line = f"({name}"
-        if isinstance(param, str):
-            line += f' "{param}")'
-        elif isinstance(param, list):
-            for item in param:
-                line += " " + str(item)
-            line += ")"
-        elif isinstance(param, bool):
-            line += f' "{str(param).lower()}")'
+        if "//" == name:
+            line = f"\n{name} {param}"
         else:
-            line += " " + str(param) + ")"
+            line = f"({name}"
+            if isinstance(param, str):
+                line += f' "{param}")'
+            elif isinstance(param, (list, tuple)):
+                for item in param:
+                    line += " " + str(item)
+                line += ")"
+            elif isinstance(param, bool):
+                line += f' "{str(param).lower()}")'
+            else:
+                line += " " + str(param) + ")"
         file.write(line + "\n")
     file.close()
 
@@ -1951,21 +2172,30 @@ def shift_translation_parameters(infile, dx=0, dy=0, dz=0, outfile=None):
     pars["TransformParameters"] = [init[0] - dx, init[1] - dy, init[2] - dz]
     write_parameters(outfile, pars)
 
-
-def get_default_pfiles(basename_only=True):
-
-    import skrt
-
-    rel_path = "data/elastix_parameter_files".split("/")
-    pdir = fullpath(os.path.join(skrt.__path__[0], *rel_path))
-    files = [file for file in os.listdir(pdir) if file.endswith(".txt")]
-    if basename_only:
-        return files
-    return [os.path.join(pdir, file) for file in files]
+def get_data_dir():
+    """Return path to data directory within the Scikit-rt package."""
+    return Path(resource_filename("skrt", "data"))
 
 def get_default_pfiles_dir():
-    """Get path to directory containing default parameter files."""
-    return str(Path(get_default_pfiles(basename_only=False)[0]).parent)
+    """Return path to directory containing default parameter files."""
+    return get_data_dir() / "elastix_parameter_files"
+
+def get_default_pfiles(basename_only=True):
+    """
+    Get list of default parameter files.
+
+    **Parameter:**
+
+    basename_only : bool, default=True
+        If True, return list of filenames only.  If True, return list
+        of paths, as pathlib.Path objects.
+    """
+
+    files = [file for file in get_default_pfiles_dir().iterdir()
+        if str(file).endswith(".txt")]
+    if basename_only:
+        return [file.name for file in files]
+    return files
 
 def get_jacobian_colormap(col_per_band=100, sat_values={0: 1, 1: 0.5, 2: 1}):
     '''
@@ -2085,3 +2315,48 @@ def get_jacobian_colormap(col_per_band=100, sat_values={0: 1, 1: 0.5, 2: 1}):
             segmentdata=cdict)
 
     return cmap
+
+def get_image_transform_parameters(im):
+    """
+    Define Elastix parameters for warping an image to the space of image <im>.
+
+    **Parameter:**
+    
+    im : skrt.image.Image
+        Image object representing a fixed image in the context of registration.
+    """
+    # Use affine matrix for defining origin and direction cosines.
+    # Seem to need to reverse sign of first two rows for agreement with
+    # convention used in Elastix - may not work for arbitrary image orientation.
+    affine = im.get_affine()
+    affine[0:2, :] = -affine[0:2, :]
+    
+    # Spacings need to be positive.
+    # Signs taken into account via direction cosines. 
+    voxel_size = [abs(dxyz) for dxyz in im.get_voxel_size()]
+
+    image_transform_parameters = {
+            "//": "Image specific",
+            "FixedImageDimension": 3,
+            "MovingImageDimension": 3,
+            "FixedInternalImagePixelType": "float",
+            "MovingInternalImagePixelType": "float",
+            "Size": im.get_n_voxels(),
+            "Index": (0, 0, 0),
+            "Spacing": voxel_size,
+            "Origin": [0 + affine[row, 3] for row in range(3)],
+            "Direction": [0 + affine[row, col] / voxel_size[col]
+                for col in range(3) for row in range(3)],
+            "UseDirectionCosines": True,
+            "//": "ResampleInterpolator specific",
+            "ResampleInterpolator": "FinalBSplineInterpolator",
+            "FinalBSplineInterpolationOrder": 3,
+            "//": "Resampler specific",
+            "Resampler": "DefaultResampler",
+            "DefaultPixelValue": 0,
+            "ResultImageFormat": "nii",
+            "ResultImagePixelType": "short",
+            "CompressResultImage": False,
+            }
+
+    return image_transform_parameters
